==> base-domain-0.0.3-20161205.055819-1-sources.jar: com/thebeastshop/scm/po/ProdSku.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import pers.richard.ormybatis.domain.po.IdPo;

public class ProdSku extends IdPo {
	private Integer productId;
	private String prodCode;
	private String skuCode;
	private String skuCategoryDesc;
	private Integer minAmount = 1;
	private Integer combined = 0;
//	private String attrs;
	private BigDecimal salesPrice;
	private BigDecimal singleSkuSalesPrice;
	private String skuCategoryName;
	private Integer active = 1;

	public ProdSku(){}
	
	public final static String
		F_PRODUCT_ID = "product_id",
		F_SKU_CODE = "sku_code",
		F_MIN_AMOUNT = "min_amount",
		F_COMBINED = "combined",
		F_SALES_PRICE = "sales_price",
		F_ACTIVE = "active";


	public Integer getProductId() {return productId;}
	public void setProductId(Integer productId) {this.productId = productId;}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuCategoryDesc() {
		return skuCategoryDesc;
	}

	public void setSkuCategoryDesc(String skuCategoryDesc) {
		this.skuCategoryDesc = skuCategoryDesc;
	}

	public Integer getMinAmount() {return minAmount;}
	public void setMinAmount(Integer minAmount) {
		if (minAmount == null) {
			minAmount = 1;
		}
		this.minAmount = minAmount;
	}

	public Integer getCombined() {return combined;}
	public void setCombined(Integer combined) {this.combined = combined;}

/*
	public String getAttrs() {
		return attrs;
	}

	public void setAttrs(String attrs) {
		this.attrs = attrs;
	}
*/

	public BigDecimal getSalesPrice() {return salesPrice;}
	public void setSalesPrice(BigDecimal salesPrice) {this.salesPrice = salesPrice;}

	public BigDecimal getSingleSkuSalesPrice() {
		return singleSkuSalesPrice;
	}

	public void setSingleSkuSalesPrice(BigDecimal singleSkuSalesPrice) {
		this.singleSkuSalesPrice = singleSkuSalesPrice;
	}

	public String getSkuCategoryName() {
		return skuCategoryName;
	}

	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}
}

==> base-domain-1.1.9-sources.jar: com/thebeastshop/scm/po/ProdSku.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import pers.richard.ormybatis.domain.po.IdPo;

public class ProdSku extends IdPo {
	private Integer productId;
	private String prodCode;
	private String skuCode;
	private String skuCategoryDesc;
	private Integer minAmount = 1;
	private Integer combined = 0;
	private String attrs;
	private BigDecimal salesPrice;
	private BigDecimal singleSkuSalesPrice;
	private String skuCategoryName;
	private Integer active = 1;
	private String bu;

	public ProdSku(){}
	
	public final static String
		F_PRODUCT_ID = "product_id",
		F_SKU_CODE = "sku_code",
		F_MIN_AMOUNT = "min_amount",
		F_COMBINED = "combined",
		F_SALES_PRICE = "sales_price",
		F_ACTIVE = "active";


	public Integer getProductId() {return productId;}
	public void setProductId(Integer productId) {this.productId = productId;}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public String getSkuCode() {return skuCode;}
	public void setSkuCode(String skuCode) {this.skuCode = skuCode;}

	public String getSkuCategoryDesc() {
		return skuCategoryDesc;
	}

	public void setSkuCategoryDesc(String skuCategoryDesc) {
		this.skuCategoryDesc = skuCategoryDesc;
	}

	public Integer getMinAmount() {return minAmount;}
	public void setMinAmount(Integer minAmount) {
		if (minAmount == null) {
			minAmount = 1;
		}
		this.minAmount = minAmount;
	}

	public Integer getCombined() {return combined;}
	public void setCombined(Integer combined) {this.combined = combined;}

	public String getAttrs() {
		return attrs;
	}

	public void setAttrs(String attrs) {
		this.attrs = attrs;
	}

	public BigDecimal getSalesPrice() {return salesPrice;}
	public void setSalesPrice(BigDecimal salesPrice) {this.salesPrice = salesPrice;}

	public BigDecimal getSingleSkuSalesPrice() {
		return singleSkuSalesPrice;
	}

	public void setSingleSkuSalesPrice(BigDecimal singleSkuSalesPrice) {
		this.singleSkuSalesPrice = singleSkuSalesPrice;
	}

	public String getSkuCategoryName() {
		return skuCategoryName;
	}

	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}

	public Integer getActive() {return active;}
	public void setActive(Integer active) {this.active = active;}

	public String getBu() {
		return bu;
	}

	public void setBu(String bu) {
		this.bu = bu;
	}
}
